@@ -7,3 +7,7 @@ class UnrecognizedSourceError(Exception):
 
 class SourceNotLoadedError(Exception):
     """Raised when data from an unloaded source is retreived."""
+
+
+class NoTMDbApiKeyError(Exception):
+    """Raised when requests are made to TMDb but no api_key has be provided."""
